@@ -1,4 +1,11 @@
-
+# -*- coding: utf-8 -*-
+"""
+@Author: HuangJianYi
+@Date: 2021-04-19 15:11:42
+@LastEditTime: 2021-09-30 16:20:46
+@LastEditors: HuangJianYi
+@Description: 
+"""
 #此文件由rigger自动生成
 from seven_framework.mysql import MySQLHelper
 from seven_framework.base_model import *
@@ -13,12 +20,12 @@ class MachineInfoModel(BaseModel):
         self.db.context = context
 
     #方法扩展请继承此类
-    
+
 class MachineInfo:
 
     def __init__(self):
         super(MachineInfo, self).__init__()
-        self.id = 0  # 
+        self.id = 0  #
         self.act_id = 0  # act_id
         self.app_id = ""  # app_id
         self.machine_name = ""  # 机台名称
@@ -40,6 +47,7 @@ class MachineInfo:
         self.series_id = 0  # IP系列id
         self.specs_type = 0  # 中盒规格(6,12)
         self.index_pic = ""  # 首页主图
+        self.machine_bg_pic = ""  # 中盒背景图
         self.goods_detail = ""  # 商品详情(json)
         self.box_style_type = 0  # 盲盒样式(1使用模板 2自定义)
         self.box_style_detail = ""  # 盲盒样式详情(json)
@@ -50,12 +58,11 @@ class MachineInfo:
 
     @classmethod
     def get_field_list(self):
-        return ['id', 'act_id', 'app_id', 'machine_name', 'machine_type', 'goods_id', 'goods_modify_date', 'sku_id', 'skin_id', 'sort_index', 'is_release', 'is_false_prize', 'is_buy_endbox', 'single_lottery_price', 'many_lottery_price', 'many_lottery_num', 'machine_price', 'is_repeat_prize', 'price_gears_id', 'series_id', 'specs_type', 'index_pic', 'goods_detail', 'box_style_type', 'box_style_detail', 'sale_type', 'sale_date', 'create_date', 'modify_date']
-        
+        return ['id', 'act_id', 'app_id', 'machine_name', 'machine_type', 'goods_id', 'goods_modify_date', 'sku_id', 'skin_id', 'sort_index', 'is_release', 'is_false_prize', 'is_buy_endbox', 'single_lottery_price', 'many_lottery_price', 'many_lottery_num', 'machine_price', 'is_repeat_prize', 'price_gears_id', 'series_id', 'specs_type', 'index_pic', 'machine_bg_pic', 'goods_detail', 'box_style_type', 'box_style_detail', 'sale_type', 'sale_date', 'create_date', 'modify_date']
+
     @classmethod
     def get_primary_key(self):
         return "id"
 
     def __str__(self):
         return "machine_info_tb"
-    
\ No newline at end of file
