@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-04-16 14:38:22
-@LastEditTime: 2022-02-17 15:55:36
+@LastEditTime: 2022-02-24 17:25:13
 @LastEditors: HuangJianYi
 :Description: 潮玩盲盒基础路由
 """
@@ -99,7 +99,7 @@ def seven_cloudapp_ppmt_route():
         (r"/server/checking_price_gear", machine_s.CheckingPriceGearHandler),  #验证价格档位
         # 2.2
         (r"/server/give_prop_list", user_s.PropGiveListHandler),
-        (r"/server/get_high_power_list", power_s.ShopPowerConfigHandler),
+        (r"/server/get_high_power_list", power_s.GetHighPowerListHandler),
         #2.4
         (r"/server/check_gm_power", app_s.CheckGmPowerHandler),  #获取是否有GM工具权限 用于GM工具
         (r"/server/get_appid_by_gm", app_s.GetAppidByGmHandler),  #根据店铺名称返回应用标识 用于GM工具
@@ -159,5 +159,5 @@ def seven_cloudapp_ppmt_route():
         #2.4
         (r"/client/get_crm_integral", user.GetCrmIntegralHandler),
         (r"/client/crm_integral_gear_list", act.CrmIntegralGearlListHandler),
-        (r"/client/get_high_power_list", power.ShopPowerConfigHandler),
+        (r"/client/get_high_power_list", power.GetHighPowerListHandler),
     ]
\ No newline at end of file
